hgext/mq.py
changeset 10361 49cd2e7fd91c
parent 10360 bcf90e712dc3
child 10362 2e3ec7ef5349
--- a/hgext/mq.py	Sun Feb 07 12:34:02 2010 +0100
+++ b/hgext/mq.py	Sun Feb 07 13:49:52 2010 +0100
@@ -1826,13 +1826,16 @@
     return 0
 
 def init(ui, repo, **opts):
     """init a new queue repository
 
     The queue repository is unversioned by default. If
     -c/--create-repo is specified, qinit will create a separate nested
     repository for patches (qinit -c may also be run later to convert
     an unversioned patch repository into a versioned one). You can use
-    qcommit to commit changes to this queue repository."""
+    qcommit to commit changes to this queue repository.
+
+    This command is depreacted. Without -c, it's implied by other relevant
+    commands. With -c, use hg -Q init instead."""
     q = repo.mq
     r = q.init(repo, create=opts['create_repo'])
     q.save_dirty()
@@ -1916,7 +1919,9 @@
             hg.update(dr, dr.changelog.tip())
 
 def commit(ui, repo, *pats, **opts):
-    """commit changes in the queue repository"""
+    """commit changes in the queue repository (DEPRECATED)
+
+    This command is deprecated; use hg -Q commit instead."""
     q = repo.mq
     r = q.qrepo()
     if not r:
@@ -1826,13 +1826,16 @@
 
 def init(ui, repo, **opts):
-    """init a new queue repository
+    """init a new queue repository (DEPRECATED)
 
     The queue repository is unversioned by default. If